@@ -8,9 +8,9 @@ Menu.model <- function(){
     degreeVar <- tclVar("NULL")
     initializeDialog(window=top, title=gettextRcmdr("Select Design and Degree"))
     degreeEntry <- ttkentry(top, width=7, textvariable=degreeVar)
-    degreelab <- ttklabel(top, text="degree")
+    degreelab <- ttklabel(top, text=gettextRcmdr("degree (positive integer)"))
     putRcmdr("sel.resps", variableListBox(top, variableList=resp.list, listHeight=10, 
-        title="Response to be analysed (select one)",selectmode="single", initialSelection=0))
+        title=gettextRcmdr("Response to be analysed (select one)"),selectmode="single", initialSelection=0))
     onOK <- function(){
         response <- getSelection(sel.resps)
         putRcmdr("resphilf", response)
